@@ -7,13 +7,13 @@ from .parser import ArgumentParser, HelpFormatter
 from .util import Arg, ArgparseArg, get_arg, join_strings, format_type, format_table
 from .util import format_arg_help, expand_error_subclasses, SimpleFrozenDict
 from .util import CommandNotFoundError, CliParserError, CommandExistsError
-from .util import ConvertersType, ErrorHandlersType
+from .util import ConverterType, ConvertersType, ErrorHandlersType
 from .util import DEFAULT_CONVERTERS, DEFAULT_PLACEHOLDER
 
 # Make available for import
-from .util import ExistingPath, ExistingFilePath, ExistingDirPath  # noqa: F401
-from .util import ExistingPathOrDash, ExistingFilePathOrDash, PathOrDash  # noqa: F401
-from .util import ExistingDirPathOrDash  # noqa: F401
+from .util import ExistingPath, ExistingFilePath, ExistingDirPath
+from .util import ExistingPathOrDash, ExistingFilePathOrDash, PathOrDash
+from .util import ExistingDirPathOrDash
 
 
 _CallableT = TypeVar("_CallableT", bound=Callable)
@@ -27,6 +27,7 @@ class Command:
     description: Optional[str] = None
     allow_extra: bool = False
     parent: Optional[str] = None
+    is_placeholder: bool = False
 
     @property
     def display_name(self) -> str:
@@ -44,6 +45,7 @@ class Radicli:
     errors: ErrorHandlersType
     _subcommand_key: str
     _help_arg: str
+    _version_arg: str
 
     def __init__(
         self,
@@ -67,6 +69,7 @@ class Radicli:
         self.errors = dict(errors) if errors is not None else {}
         self._subcommand_key = "__subcommand__"  # should not conflict with arg name!
         self._help_arg = "--help"
+        self._version_arg = "--version"
 
     # Using underscored argument names here to prevent conflicts if CLI commands
     # define arguments called "name" that are passed in via **args
@@ -163,7 +166,7 @@ class Radicli:
                 err = f"argument not found in function for '{path}': {param}"
                 raise CliParserError(err)
 
-            def get_converter(arg_type: Type) -> Optional[Callable[[str], Any]]:
+            def get_converter(arg_type: Type) -> Optional[ConverterType]:
                 return self.converters.get(arg_type, arg_info.converter)
 
             param_type = sig_types[param]
@@ -199,7 +202,9 @@ class Radicli:
             # If this runs, we want to show the help instead of doing nothing
             self.parse(["--help"], [], subcommands, name=name, description=description)
 
-        dummy = Command(name=name, func=func, args=[], description=description)
+        dummy = Command(
+            name=name, func=func, args=[], description=description, is_placeholder=True
+        )
         self.commands[name] = dummy
 
     def run(self, args: Optional[List[str]] = None) -> None:
@@ -218,6 +223,9 @@ class Radicli:
                     run_args.insert(1, single_cmd)
             command = run_args.pop(1)
             args = run_args[1:]
+            if self.version and command == self._version_arg:
+                print(self.version)
+                sys.exit(0)
             subcommands = self.subcommands.get(command, {})
             if command not in self.commands:
                 if not subcommands:
@@ -266,7 +274,7 @@ class Radicli:
             argument_default=DEFAULT_PLACEHOLDER,
         )
         if self.version:
-            p.add_argument("--version", action="version", version=self.version)
+            p.add_argument(self._version_arg, action="version", version=self.version)
         self._add_args(p, arg_info)
         subparsers: Dict[str, Tuple[ArgumentParser, Command]] = {}
         if subcommands:
@@ -350,3 +358,15 @@ class Radicli:
                 data.append((f"  {name}", col))
         info = [self.help, "\nAvailable commands:", format_table(data)]
         return join_strings(*info, char="\n")
+
+
+# fmt: off
+__all__ = [
+    "Radicli", "ArgumentParser", "HelpFormatter", "Command", "Arg", "ArgparseArg",
+    "get_arg", "format_type", "CommandNotFoundError", "CliParserError",
+    "CommandExistsError", "ConvertersType", "ConverterType", "ErrorHandlersType",
+    "DEFAULT_PLACEHOLDER", "ExistingPath", "ExistingFilePath", "ExistingDirPath",
+    "ExistingPathOrDash", "ExistingFilePathOrDash", "PathOrDash",
+    "ExistingDirPathOrDash"
+]
+# fmt: on
